@@ -1,7 +1,7 @@
 /*
  * LavaLauncher - A simple launcher panel for Wayland
  *
- * Copyright (C) 2020 Leon Plickat <leonhenrik.plickat@stud.uni-goettingen.de>
+ * Copyright (C) 2020 Leon Henrik Plickat
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,8 +20,12 @@
 #ifndef LAVALAUNCHER_CURSOR_H
 #define LAVALAUNCHER_CURSOR_H
 
-void attach_cursor_surface (struct Lava_data *data, struct wl_pointer *wl_pointer, uint32_t serial);
-bool init_cursor (struct Lava_data *data);
-void finish_cursor (struct Lava_data *data);
+#include<stdint.h>
+
+struct Lava_seat;
+
+void cleanup_cursor (struct Lava_seat *seat);
+void attach_cursor (struct Lava_seat *seat, uint32_t serial);
 
 #endif
+
